### Add simple-git-hooks to the project

1. Install simple-git-hooks as a dev dependency:
   
   ```sh
   npm install simple-git-hooks --save-dev
   ```

2. Add `simple-git-hooks` to your `package.json`. Fill it with git hooks and the corresponding commands.

    For example:

    ```json
    {
      "simple-git-hooks": {
        "pre-commit": "npx lint-staged",
        "pre-push": "cd ../../ && npm run format"
      }
    }
    ```

    This configuration is going to run all linters on every `commit` and formatter on `push`.
    
   > There are more ways to configure the package. Check out [Additional configuration options](#additional-configuration-options).
    
3. Run the CLI script to update the git hooks with the commands from the config:

   ```sh
   npx simple-git-hooks
   ```
    
Now all the git hooks are created.

### Update git hooks command

1. Change the configuration.

2. Run `npx simple-git-hooks` **from the root of your project**.

Note for **yarn2** users: Please run `yarn dlx simple-git-hooks` instead of the command above. More info on [dlx](https://yarnpkg.com/cli/dlx)

Note that you should manually run `npx simple-git-hooks` **every time you change a command**.


### Additional configuration options

You can also add a `.simple-git-hooks.js`, `simple-git-hooks.js`, `.simple-git-hooks.json` or `simple-git-hooks.json` file to the project and write the configuration inside it.

This way `simple-git-hooks` configuration in `package.json` will not take effect any more.

`.simple-git-hooks.js` or `simple-git-hooks.js` should look like the following.

```js
module.exports = {
  "pre-commit": "npx lint staged",
  "pre-push": "cd ../../ && npm run format"
}
```

`.simple-git-hooks.json` or `simple-git-hooks.json` should look like the following.

```json
{
  "pre-commit": "npx lint staged",
  "pre-push": "cd ../../ && npm run format"
}
```
